@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.31 2002/05/14 01:32:13 gman Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.31.2.1 2002/07/15 21:58:33 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -82,6 +82,7 @@ static void pref_data_cb            (dict_command_t *command, dict_res_t *res,
 static void pref_dialog_ok_cb       (GtkWidget *widget, gpointer data);
 static void pref_dialog_apply_cb    (GtkWidget *widget, gpointer data);
 static void pref_dialog_close_cb    (GtkWidget *widget, gpointer data);
+static void phelp_cb		    (GtkDialog *dialog, gint response);
 static void response_cb		    (GtkDialog *dialog, gint response);
 static gboolean	set_server_cb 	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
 static gboolean set_port_cb	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
@@ -270,8 +271,8 @@ create_dialog (GDictPrefDialog *pref_dialog)
     
     gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
 
-    gtk_dialog_add_button (GTK_DIALOG (pref_dialog), GTK_STOCK_CLOSE,
-    			   GTK_RESPONSE_CLOSE);  
+    gtk_dialog_add_buttons (GTK_DIALOG (pref_dialog), GTK_STOCK_CLOSE,
+    			    GTK_RESPONSE_CLOSE, GTK_STOCK_HELP, GTK_RESPONSE_HELP, NULL);  
 
     gtk_dialog_set_default_response (GTK_DIALOG (pref_dialog), GTK_RESPONSE_CLOSE);
     
@@ -642,6 +643,11 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
 static void 
 response_cb (GtkDialog *dialog, gint response)
 {
+    if(response == GTK_RESPONSE_HELP)
+    {
+       phelp_cb (dialog, response);
+       return;
+    }
     gtk_widget_hide (GTK_WIDGET (dialog));
 }
 
@@ -741,3 +747,29 @@ smart_lookup_cb	(GtkToggleButton *toggle, gpointer data)
     
 
 }
+
+static void
+phelp_cb    (GtkDialog *dialog, gint response)
+{
+	GError *error = NULL;
+	gnome_help_display("gnome-dictionary","gdict-settings",&error);
+
+	if (error) {
+		GtkWidget *msg_dialog;
+
+		msg_dialog = gtk_message_dialog_new (GTK_WINDOW(dialog),
+						     GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_MESSAGE_ERROR,
+						     GTK_BUTTONS_CLOSE,
+						     ("There was an error displaying help: \n%s"),
+						     error->message);
+
+		g_signal_connect (G_OBJECT (msg_dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (msg_dialog), FALSE);
+		gtk_widget_show (msg_dialog);
+		g_error_free (error);
+	}
+}
